%global __cmake_in_source_build 1

%global commitid 7fd4828c934fccf7367499c9e01cc9a1e90a2093
%global gitversion 7fd482
# gitdate 20200303

Summary:    An open-source library for mathematical programming
Name:       mp
Version:    3.1.0
Release:    4.git%{gitversion}%{?dist}
License:    MIT and BSD
URL:        https://github.com/ampl/mp
Source0:    %{url}/archive/%{gitversion}/mp-%{gitversion}.tar.gz
Source1:    %{name}.module.in
# https://github.com/ampl/ampl.github.io.git
# commitid ccf1ff9f109d09ea0d42c60b6f26323312a99c42
# gitdate 20190321
Source2:    ampl.github.io.tar.xz

Patch3000:  %{name}-strtod.patch
Patch3001:  %{name}-%{version}-jni.patch
Patch3002:  %{name}-python3.patch
Patch3003:  %{name}-jvm-destructor.patch

BuildRequires: cmake3 gcc-c++
BuildRequires: environment(modules) chrpath doxygen gdb git-core
BuildRequires: flexiblas-devel pkgconfig(gsl) python3-devel
Requires:      environment(modules)
Provides:      bundled(fmt) = 3.0.1

%global majver %(cut -d. -f1 <<< %{version})

%description
MP library is a set of solver drivers and tools recommended
to create new AMPL solver drivers. It provides type-safe and
flexible interfaces suitable for linear and mixed-integer,
non-linear, and Constraint Programming solvers.

%package devel
Summary: Development files for %{name}
Requires: %{name} = %{version}-%{release}

%description devel
This package contains the header files for %{name}.

%package doc
Summary: Documentation for %{name}

%description doc
This package contains the developer documentation for %{name}.

%prep
%autosetup -n %{name}-%{commitid} -a 2 -p1

for fil in $(find ampl.github.io/models -type f); do
  type=$(file $fil)
  if [[ "$type" =~ "with CRLF" ]]; then
    sed -i.orig 's/\r//' $fil
    touch -r $fil.orig $fil
    rm -f $fil.orig
  fi
  if [[ "$type" =~ "ISO-8859" ]]; then
    mv $fil $fil.orig
    iconv -f ISO8859-1 -t UTF-8 $fil.orig > $fil
    touch -r $fil.orig $fil
    rm -f $fil.orig
  fi
done

sed -i 's,returncode == 0,False,' support/build-docs.py

%build
export LIBS="-lgsl -lflexiblas"
mkdir -p build && pushd build
BUILD="asl,gsl,smpswriter"
export CPPFLAGS="-I$PWD/src/asl/solvers"
export CFLAGS="%{optflags} -DNDEBUG"
export CXXFLAGS="%{optflags} -DNDEBUG"
%cmake3 -DCMAKE_INSTALL_PREFIX:PATH=%{_libdir}/%{name} \
 -DCMAKE_SHARED_LINKER_FLAGS:STRING="$LDFLAGS" \
 -DCMAKE_CXX_FLAGS_RELEASE:STRING="$CXXFLAGS" \
 -DCMAKE_C_FLAGS_RELEASE:STRING="$CFLAGS" \
 -DCMAKE_SKIP_INSTALL_RPATH:BOOL=NO \
 -DCMAKE_SKIP_RPATH:BOOL=NO \
 -DCMAKE_VERBOSE_MAKEFILE:BOOL=YES \
 -DGENERATE_ARITH:BOOL=YES \
 -DBUILD_SHARED_LIBS:BOOL=YES \
 -DBUILD:STRING=$BUILD ..
%make_build
make doc
rm doc/ampl.github.io/models/*/.depend
popd

%install
mkdir -p %{buildroot}%{_modulesdir}
sed 's#@BINDIR@#'%{_libdir}/%{name}'#g;' < %{SOURCE1} > %{buildroot}%{_modulesdir}/%{name}-%{_arch}

mkdir -p %{buildroot}%{_libdir}/%{name}/bin/lib
mkdir -p %{buildroot}%{_includedir}/asl
cp -a include %{buildroot}%{_prefix}
install -pm 644 src/asl/*.h %{buildroot}%{_includedir}/asl
install -pm 644 src/asl/solvers/*.h build/src/asl/*.h %{buildroot}%{_includedir}/asl
install -pm 644 src/asl/solvers/{opcode,r_opn}.hd %{buildroot}%{_includedir}/asl

install -pm 755 build/bin/amplgsl.dll %{buildroot}%{_libdir}/%{name}/bin
install -pm 755 build/bin/ampltabl.dll %{buildroot}%{_libdir}/%{name}/bin
install -pm 755 build/bin/arithchk %{buildroot}%{_libdir}/%{name}/bin
install -pm 755 build/bin/cp.dll %{buildroot}%{_libdir}/%{name}/bin
install -pm 755 build/bin/fullbit.dll %{buildroot}%{_libdir}/%{name}/bin
install -pm 755 build/bin/gen-expr-info %{buildroot}%{_libdir}/%{name}/bin
install -pm 755 build/bin/gjh %{buildroot}%{_libdir}/%{name}/bin
install -pm 755 build/bin/gsl-info %{buildroot}%{_libdir}/%{name}/bin
install -pm 755 build/bin/libamplsmpswriter.so %{buildroot}%{_libdir}/%{name}/bin
install -pm 755 build/bin/simpbit.dll %{buildroot}%{_libdir}/%{name}/bin
install -pm 755 build/bin/smpswriter %{buildroot}%{_libdir}/%{name}/bin
install -pm 755 build/bin/tableproxy%{__isa_bits} %{buildroot}%{_libdir}/%{name}/bin

install -pm 755 build/bin/libasl.so* %{buildroot}%{_libdir}
ln -sf libasl.so.%{version} %{buildroot}%{_libdir}/libasl.so.%{majver}
ln -sf libasl.so.%{majver} %{buildroot}%{_libdir}/libasl.so

install -pm 755 build/bin/libmp.so* %{buildroot}%{_libdir}
ln -sf libmp.so.%{version} %{buildroot}%{_libdir}/libmp.so.%{majver}
ln -sf libmp.so.%{majver} %{buildroot}%{_libdir}/libmp.so

chrpath --delete %{buildroot}%{_libdir}/libasl.so.%{version}
chrpath --delete %{buildroot}%{_libdir}/%{name}/bin/amplgsl.dll
chrpath --delete %{buildroot}%{_libdir}/%{name}/bin/ampltabl.dll
chrpath --delete %{buildroot}%{_libdir}/%{name}/bin/arithchk
chrpath --delete %{buildroot}%{_libdir}/%{name}/bin/cp.dll
chrpath --delete %{buildroot}%{_libdir}/%{name}/bin/fullbit.dll
chrpath --delete %{buildroot}%{_libdir}/%{name}/bin/gen-expr-info
chrpath --delete %{buildroot}%{_libdir}/%{name}/bin/gjh
chrpath --delete %{buildroot}%{_libdir}/%{name}/bin/gsl-info
chrpath --delete %{buildroot}%{_libdir}/%{name}/bin/libamplsmpswriter.so
chrpath --delete %{buildroot}%{_libdir}/%{name}/bin/simpbit.dll
chrpath --delete %{buildroot}%{_libdir}/%{name}/bin/smpswriter
chrpath --delete %{buildroot}%{_libdir}/%{name}/bin/tableproxy%{__isa_bits}

%check
pushd build
ctest --force-new-ctest-process -j1
popd


%files
%license LICENSE.rst
%doc README.rst
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/bin/
%{_libdir}/libasl.so.3*
%{_libdir}/libmp.so.3*
%{_modulesdir}/%{name}-%{_arch}

%files devel
%{_libdir}/libasl.so
%{_libdir}/libmp.so
%{_includedir}/asl
%{_includedir}/mp

%files doc
%license LICENSE.rst
%doc build/doc/ampl.github.io/*

%changelog
* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.1.0-4.git7fd482
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.1.0-3.git7fd482
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.1.0-2.git7fd482
- Rebuilt for OpenCloudOS Stream 23

* Tue Mar 28 2023 Miaojun Dong <zoedong@tencent.com> - 3.1.0-1
- initial build
